==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIRectEdge.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 7.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Marshaler(Bits.AsMachineSizedIntMarshaler.class)/*</annotations>*/
public final class /*<name>*/UIRectEdge/*</name>*/ extends Bits</*<name>*/UIRectEdge/*</name>*/> {
    /*<values>*/
    public static final UIRectEdge None = new UIRectEdge(0L);
    public static final UIRectEdge Top = new UIRectEdge(1L);
    public static final UIRectEdge Left = new UIRectEdge(2L);
    public static final UIRectEdge Bottom = new UIRectEdge(4L);
    public static final UIRectEdge Right = new UIRectEdge(8L);
    public static final UIRectEdge All = new UIRectEdge(15L);
    /*</values>*/

    private static final /*<name>*/UIRectEdge/*</name>*/[] values = _values(/*<name>*/UIRectEdge/*</name>*/.class);

    public /*<name>*/UIRectEdge/*</name>*/(long value) { super(value); }
    private /*<name>*/UIRectEdge/*</name>*/(long value, long mask) { super(value, mask); }
    protected /*<name>*/UIRectEdge/*</name>*/ wrap(long value, long mask) {
        return new /*<name>*/UIRectEdge/*</name>*/(value, mask);
    }
    protected /*<name>*/UIRectEdge/*</name>*/[] _values() {
        return values;
    }
    public static /*<name>*/UIRectEdge/*</name>*/[] values() {
        return values.clone();
    }
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/uikit/UIRectEdge.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Marshaler(Bits.AsMachineSizedIntMarshaler.class)/*</annotations>*/
public final class /*<name>*/UIRectEdge/*</name>*/ extends Bits</*<name>*/UIRectEdge/*</name>*/> {
    /*<values>*/
    public static final UIRectEdge None = new UIRectEdge(0L);
    public static final UIRectEdge Top = new UIRectEdge(1L);
    public static final UIRectEdge Left = new UIRectEdge(2L);
    public static final UIRectEdge Bottom = new UIRectEdge(4L);
    public static final UIRectEdge Right = new UIRectEdge(8L);
    public static final UIRectEdge All = new UIRectEdge(15L);
    /*</values>*/

    private static final /*<name>*/UIRectEdge/*</name>*/[] values = _values(/*<name>*/UIRectEdge/*</name>*/.class);

    public /*<name>*/UIRectEdge/*</name>*/(long value) { super(value); }
    private /*<name>*/UIRectEdge/*</name>*/(long value, long mask) { super(value, mask); }
    protected /*<name>*/UIRectEdge/*</name>*/ wrap(long value, long mask) {
        return new /*<name>*/UIRectEdge/*</name>*/(value, mask);
    }
    protected /*<name>*/UIRectEdge/*</name>*/[] _values() {
        return values;
    }
    public static /*<name>*/UIRectEdge/*</name>*/[] values() {
        return values.clone();
    }
}
